@@ -37,6 +37,7 @@ extern "C" {
 #endif
 
 #define LIBNFS_FEATURE_READAHEAD
+#define LIBNFS_FEATURE_DEBUG
 #define NFS_BLKSIZE 4096
 
 struct nfs_context;
@@ -190,6 +191,7 @@ EXTERN void nfs_set_tcp_syncnt(struct nfs_context *nfs, int v);
 EXTERN void nfs_set_uid(struct nfs_context *nfs, int uid);
 EXTERN void nfs_set_gid(struct nfs_context *nfs, int gid);
 EXTERN void nfs_set_readahead(struct nfs_context *nfs, uint32_t v);
+EXTERN void nfs_set_debug(struct nfs_context *nfs, int level);
 
 /*
  * MOUNT THE EXPORT
