@@ -62,21 +62,28 @@ struct rpc_context *rpc_init_context(void)
 
 	rpc->magic = RPC_CONTEXT_MAGIC;
 
-	/* Allow 1M of data (for writes) and some */
-	rpc->encodebuflen = 1024 * 1024 + 4096;
+	/* Allow NFS_MAX_XFER_SIZE of data (for writes) and some */
+	rpc->encodebuflen = NFS_MAX_XFER_SIZE + 4096;
 	rpc->encodebuf = malloc(rpc->encodebuflen);
 	if (rpc->encodebuf == NULL) {
 		free(rpc);
 		return NULL;
 	}
 
+	rpc->inbuflen = 2 * (NFS_MAX_XFER_SIZE + 4096);
+	rpc->inbuf = malloc(rpc->inbuflen);
+	if (rpc->inbuf == NULL) {
+		free(rpc);
+		return NULL;
+	}
+
  	rpc->auth = authunix_create_default();
 	if (rpc->auth == NULL) {
 		free(rpc->encodebuf);
 		free(rpc);
 		return NULL;
 	}
-	rpc->xid = salt + time(NULL) + getpid() << 16;
+	rpc->xid = salt + time(NULL) + (getpid() << 16);
 	salt += 0x01000000;
 	rpc->fd = -1;
 	rpc->tcp_syncnt = RPC_PARAM_UNDEFINED;
@@ -101,6 +108,13 @@ void rpc_set_readahead(struct rpc_context *rpc, uint32_t v)
 	rpc->readahead = v;
 }
 
+void rpc_set_debug(struct rpc_context *rpc, int level)
+{
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
+	rpc->debug = level;
+}
+
 struct rpc_context *rpc_init_udp_context(void)
 {
 	struct rpc_context *rpc;
@@ -142,7 +156,7 @@ void rpc_set_gid(struct rpc_context *rpc, int gid) {
 	rpc_set_uid_gid(rpc, rpc->uid, gid);
 }
 
-void rpc_set_error(struct rpc_context *rpc, char *error_string, ...)
+void rpc_set_error(struct rpc_context *rpc, const char *error_string, ...)
 {
         va_list ap;
 	char *old_error_string = rpc->error_string;
@@ -154,6 +168,8 @@ void rpc_set_error(struct rpc_context *rpc, char *error_string, ...)
 	vsnprintf(rpc->error_string, 1024, error_string, ap);
         va_end(ap);
 
+	fprintf(stderr, "libnfs error: %s\n", rpc->error_string);
+
 	if (old_error_string != NULL) {
 		free(old_error_string);
 	}
@@ -166,15 +182,15 @@ char *rpc_get_error(struct rpc_context *rpc)
 	return rpc->error_string;
 }
 
-void rpc_error_all_pdus(struct rpc_context *rpc, char *error)
+void rpc_error_all_pdus(struct rpc_context *rpc, const char *error)
 {
-	struct rpc_pdu *pdu, *next;
+	struct rpc_pdu *pdu;
 	unsigned int i;
 
 	assert(rpc->magic == RPC_CONTEXT_MAGIC);
 
 	while ((pdu = rpc->outqueue.head) != NULL) {
-		pdu->cb(rpc, RPC_STATUS_ERROR, error, pdu->private_data);
+          pdu->cb(rpc, RPC_STATUS_ERROR, (void *)error, pdu->private_data);
 		rpc->outqueue.head = pdu->next;
 		rpc_free_pdu(rpc, pdu);
 	}
@@ -184,7 +200,8 @@ void rpc_error_all_pdus(struct rpc_context *rpc, char *error)
 		struct rpc_queue *q = &rpc->waitpdu[i];
 
 		while((pdu = q->head) != NULL) {
-			pdu->cb(rpc, RPC_STATUS_ERROR, error, pdu->private_data);
+                  pdu->cb(rpc, RPC_STATUS_ERROR, (void *)error,
+                          pdu->private_data);
 			q->head = pdu->next;
 			rpc_free_pdu(rpc, pdu);
 		}
@@ -267,20 +284,10 @@ void rpc_destroy_context(struct rpc_context *rpc)
  		close(rpc->fd);
 	}
 
-	if (rpc->encodebuf != NULL) {
-		free(rpc->encodebuf);
-		rpc->encodebuf = NULL;
-	}
-
-	if (rpc->error_string != NULL) {
-		free(rpc->error_string);
-		rpc->error_string = NULL;
-	}
-
-	if (rpc->udp_dest != NULL) {
-		free(rpc->udp_dest);
-		rpc->udp_dest = NULL;
-	}
+	free(rpc->encodebuf);
+	free(rpc->inbuf);
+	free(rpc->error_string);
+	free(rpc->udp_dest);
 
 	rpc->magic = 0;
 	free(rpc);
